bayespy.nodes.Exponential
=========================

.. currentmodule:: bayespy.nodes

.. autoclass:: Exponential

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Exponential.__init__
      ~Exponential.add_plate_axis
      ~Exponential.as_diagonal_wishart
      ~Exponential.broadcasting_multiplier
      ~Exponential.delete
      ~Exponential.get_gradient
      ~Exponential.get_mask
      ~Exponential.get_moments
      ~Exponential.get_parameters
      ~Exponential.get_riemannian_gradient
      ~Exponential.get_shape
      ~Exponential.has_plotter
      ~Exponential.initialize_from_parameters
      ~Exponential.initialize_from_prior
      ~Exponential.initialize_from_random
      ~Exponential.initialize_from_value
      ~Exponential.load
      ~Exponential.logpdf
      ~Exponential.lower_bound_contribution
      ~Exponential.lowerbound
      ~Exponential.move_plates
      ~Exponential.observe
      ~Exponential.pdf
      ~Exponential.plot
      ~Exponential.random
      ~Exponential.save
      ~Exponential.set_parameters
      ~Exponential.set_plotter
      ~Exponential.show
      ~Exponential.unobserve
      ~Exponential.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Exponential.dims
      ~Exponential.plates
      ~Exponential.plates_multiplier
   
   